/*
 * Copyright 2000, International Business Machines Corporation and others.
 * All Rights Reserved.
 *
 * This software has been released under the terms of the IBM Public
 * License.  For details, see the LICENSE file in the top-level source
 * directory or online at http://www.openafs.org/dl/license10.html
 */

#ifndef OPENAFS_AFS_UKERNEL_AFSINCLUDES_H
#define OPENAFS_AFS_UKERNEL_AFSINCLUDES_H 1

/* AFS based headers */
#include "afs/stds.h"
#include "rx/rx.h"
#include "afs/afs_osi.h"
#include "afs/lock.h"
#include "afs/volerrors.h"
#include "afs/voldefs.h"
#include "afsint.h"
#include "afs/exporter.h"
#include "vldbint.h"
#include "afs/afs.h"
#include "afs/afs_chunkops.h"
#include "rx/rxkad.h"
#include "afs/prs_fs.h"
#include "afs/dir.h"
#include "afs/afs_axscache.h"
#include "afs/icl.h"
#include "afs/afs_stats.h"
#include "afs/afs_prototypes.h"
#include "afs/discon.h"
#include "roken.h"

#endif /* OPENAFS_AFS_UKERNEL_AFSINCLUDES_H */